package com.cgi.cihr.model;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Model for checked-out volumes.
 * 
 * @author tomas.hansson
 */
public class CheckOut {
	private String user;
	private String comment;
	private String location;
	private Date coDate;
	private Date wantedDate;
	
	/**
	 * Constructor. 
	 * 
	 * @param user
	 * @param comment
	 * @param location
	 * @param coDate
	 * @param wantedDate
	 */
	public CheckOut(String user, String comment, String location,
			Date coDate, Date wantedDate) {
		this.user = user;
		this.comment = comment;
		this.location = location;
		this.coDate = coDate;
		this.wantedDate = wantedDate;
	}

	/**
	 * @return the user
	 */
	public String getUser() {
		return user;
	}
	
	/**
	 * @param user the user to set
	 */
	public void setUser(String user) {
		this.user = user;
	}
	
	/**
	 * @return the comment
	 */
	public String getComment() {
		return comment;
	}

	/**
	 * @param comment the comment to set
	 */
	public void setComment(String comment) {
		this.comment = comment;
	}

	/**
	 * @return the location
	 */
	public String getLocation() {
		return location;
	}

	/**
	 * @param location the location to set
	 */
	public void setLocation(String location) {
		this.location = location;
	}

	/**
	 * @return the coDate
	 */
	public Date getCoDate() {
		return coDate;
	}
	
	/**
	 * @param coDate the coDate to set
	 */
	public void setCoDate(Date coDate) {
		this.coDate = coDate;
	}
		
	/**
	 * @return the wantedDate
	 */
	public Date getWantedDate() {
		return wantedDate;
	}

	/**
	 * @param wantedDate the wantedDate to set
	 */
	public void setWantedDate(Date wantedDate) {
		this.wantedDate = wantedDate;
	}

	/**
	 * Write string.
	 * 
	 * @return String
	 */
	public String toString() {
		return "CheckOut [user=" + user + ", comment="
				+ comment + ", location=" + location
				+ ", coDate=" + coDate + ", wantedDate=" + wantedDate + "]";
	}

	/**
	 * Write the borrow as Importer XML string.
	 * 
	 * @return String
	 */
	public String toXMLString() {
		DateFormat df = new SimpleDateFormat("yyyyMMdd");

		String xml = "    <borrow action=\"borrow\">\n" +
			"      <borrower>" + user + "</borrower>\n" +
			"      <comment>" + comment + "</comment>\n" +
			"      <location>" + location + "</location>\n" +
			"      <borrowdate>" + df.format(coDate) + "</borrowdate>\n" +
			"      <returndate>" + df.format(wantedDate) + "</returndate>\n" +
			"      <copynum>1</copynum>\n" + 
			"      <securityoverride>1</securityoverride>\n" +
			"    </borrow>\n";
		
		return xml;
	}
}
