package com.cgi.cihr.model;

import java.util.Date;

import org.apache.commons.lang.StringEscapeUtils;

import com.cgi.tools.DateUtils;

/**
 * PROFF Box model.
 * 
 * @author tomas.hansson
 */
public class ProffBox {
	private static String CATEGORY = "PROFF Box";
	private static String BOX_TITLE = "Box Title";
	private static String LOCATION = "Location";
	private static String ACCESS_NUMBER = "Access Number";
	private static String DISPOSAL_DATE = "Disposal Date";

	private String boxTitle;
	private String location;
	private String accessNumber;
	private Date disposalDate;
	
	/**
	 * @param boxTitle
	 * @param location
	 * @param accessNumber
	 * @param disposalDate
	 */
	public ProffBox(String boxTitle, String location, String accessNumber,
			Date disposalDate) {
		this.boxTitle = boxTitle;
		this.location = location;
		this.accessNumber = accessNumber;
		this.disposalDate = disposalDate;
	}


	/**
	 * @return the boxTitle
	 */
	public String getBoxTitle() {
		return boxTitle;
	}


	/**
	 * @param boxTitle the boxTitle to set
	 */
	public void setBoxTitle(String boxTitle) {
		this.boxTitle = boxTitle;
	}


	/**
	 * @return the location
	 */
	public String getLocation() {
		return location;
	}


	/**
	 * @param location the location to set
	 */
	public void setLocation(String location) {
		this.location = location;
	}


	/**
	 * @return the accessNumber
	 */
	public String getAccessNumber() {
		return accessNumber;
	}


	/**
	 * @param accessNumber the accessNumber to set
	 */
	public void setAccessNumber(String accessNumber) {
		this.accessNumber = accessNumber;
	}


	/**
	 * @return the disposalDate
	 */
	public Date getDisposalDate() {
		return disposalDate;
	}


	/**
	 * @param disposalDate the disposalDate to set
	 */
	public void setDisposalDate(Date disposalDate) {
		this.disposalDate = disposalDate;
	}

	/**
	 * To string.
	 * 
	 * @return String
	 */
	public String toString() {
		return "ProffBox [boxTitle=" + boxTitle + ", location=" + location
				+ ", accessNumber=" + accessNumber + ", disposalDate="
				+ disposalDate + "]";
	}


	/**
	 * Write the category as Importer XML string.
	 * 
	 * @return String
	 */
	public String toXMLString() {
		StringBuffer xml = new StringBuffer();
		
		xml.append("    <category name=\"Livelink Categories:" + CATEGORY + "\">\n");
		
		if (boxTitle != null) {
			xml.append("      <attribute name=\"" + BOX_TITLE + "\">" +
					StringEscapeUtils.escapeXml(boxTitle) + "</attribute>\n");
		}
		
		if (location != null) {
			xml.append("      <attribute name=\"" + LOCATION + "\">" + 
					StringEscapeUtils.escapeXml(location) + "</attribute>\n");
		}

		if (accessNumber != null) {
			xml.append("      <attribute name=\"" + ACCESS_NUMBER + "\">" + 
					StringEscapeUtils.escapeXml(accessNumber) + "</attribute>\n");
		}

		if (disposalDate != null) {
			xml.append("      <attribute name=\"" + DISPOSAL_DATE + "\">" + 
					DateUtils.formatDate(disposalDate) + "</attribute>\n");
		}

		xml.append("    </category>\n");
		
		return xml.toString();
	}
}
