package com.cgi.cihr.model;

import java.util.Date;

import org.apache.commons.lang.StringEscapeUtils;

import com.cgi.tools.DateUtils;

/**
 * PROFF Document model.
 * 
 * @author tomas.hansson
 */
public class ProffDocument {
	private static String CATEGORY = "PROFF Document";
	private static String DOCUMENT_NO = "Document No";
	private static String PROFF_SERIES = "PROFF Series";
	private static String DOCUMENT_TYPE = "Document Type";
	private static String RECEIVED_DATE = "Received Date";
	private static String CREATED_DATE = "Created Date";
	private static String TO_PERSON = "To Person";
	private static String FROM_PERSON = "From Person";
	private static String DISPOSITION_DATE = "Disposition Date";
	private static String MASTER_DOCUMENT = "Master Document";

	private int documentNo;
	private String proffSeries;
	private String documentType;
	private Date receivedDate;
	private Date createdDate;
	private String toPerson;
	private String fromPerson;
	private Date dispositionDate;
	private int masterDocument;
	
	/**
	 * @param documentNo
	 * @param proffSeries
	 * @param documentType
	 * @param receivedDate
	 * @param createdDate
	 * @param toPerson
	 * @param fromPerson
	 * @param dispositionDate
	 * @param masterDocument
	 */
	public ProffDocument(int documentNo, String proffSeries,
			String documentType, String receivedDate, String createdDate,
			String toPerson, String fromPerson, String dispositionDate,
			Object masterDocument) {
		this.documentNo = documentNo;
		this.proffSeries = proffSeries;
		this.documentType = documentType;
		this.receivedDate = DateUtils.createDate(receivedDate);
		this.createdDate = DateUtils.createDate(createdDate);
		this.toPerson = toPerson;
		this.fromPerson = fromPerson;
		this.dispositionDate = DateUtils.createDate(dispositionDate);
		this.masterDocument = (masterDocument == null ? 0 : (Integer) masterDocument);
	}


	/**
	 * @return the documentNo
	 */
	public int getDocumentNo() {
		return documentNo;
	}


	/**
	 * @param documentNo the documentNo to set
	 */
	public void setDocumentNo(int documentNo) {
		this.documentNo = documentNo;
	}


	/**
	 * @return the proffSeries
	 */
	public String getProffSeries() {
		return proffSeries;
	}


	/**
	 * @param proffSeries the proffSeries to set
	 */
	public void setProffSeries(String proffSeries) {
		this.proffSeries = proffSeries;
	}


	/**
	 * @return the documentType
	 */
	public String getDocumentType() {
		return documentType;
	}


	/**
	 * @param documentType the documentType to set
	 */
	public void setDocumentType(String documentType) {
		this.documentType = documentType;
	}


	/**
	 * @return the receivedDate
	 */
	public Date getReceivedDate() {
		return receivedDate;
	}


	/**
	 * @param receivedDate the receivedDate to set
	 */
	public void setReceivedDate(Date receivedDate) {
		this.receivedDate = receivedDate;
	}


	/**
	 * @return the createdDate
	 */
	public Date getCreatedDate() {
		return createdDate;
	}


	/**
	 * @param createdDate the createdDate to set
	 */
	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}


	/**
	 * @return the toPerson
	 */
	public String getToPerson() {
		return toPerson;
	}


	/**
	 * @param toPerson the toPerson to set
	 */
	public void setToPerson(String toPerson) {
		this.toPerson = toPerson;
	}


	/**
	 * @return the fromPerson
	 */
	public String getFromPerson() {
		return fromPerson;
	}


	/**
	 * @param fromPerson the fromPerson to set
	 */
	public void setFromPerson(String fromPerson) {
		this.fromPerson = fromPerson;
	}


	/**
	 * @return the dispositionDate
	 */
	public Date getDispositionDate() {
		return dispositionDate;
	}


	/**
	 * @param dispositionDate the dispositionDate to set
	 */
	public void setDispositionDate(Date dispositionDate) {
		this.dispositionDate = dispositionDate;
	}


	/**
	 * @return the masterDocument
	 */
	public int getMasterDocument() {
		return masterDocument;
	}


	/**
	 * @param masterDocument the masterDocument to set
	 */
	public void setMasterDocument(int masterDocument) {
		this.masterDocument = masterDocument;
	}

	/**
	 * To String.
	 * 
	 * @return String
	 */
	public String toString() {
		return "ProffDocument [documentNo=" + documentNo + ", proffSeries="
				+ proffSeries + ", documentType=" + documentType
				+ ", receivedDate=" + receivedDate + ", createdDate="
				+ createdDate + ", toPerson=" + toPerson + ", fromPerson="
				+ fromPerson + ", dispositionDate=" + dispositionDate
				+ ", masterDocument=" + masterDocument + "]";
	}


	/**
	 * Write the category as Importer XML string.
	 * 
	 * @return String
	 */
	public String toXMLString() {
		StringBuffer xml = new StringBuffer();
		
		xml.append("    <category name=\"Livelink Categories:" + CATEGORY + "\">\n");
		xml.append("      <attribute name=\"" + DOCUMENT_NO + "\">" + documentNo + "</attribute>\n");
		xml.append("      <attribute name=\"" + PROFF_SERIES + "\">" + proffSeries + "</attribute>\n");
		
		if (documentType != null) {
			xml.append("      <attribute name=\"" + DOCUMENT_TYPE + "\">" + documentType + "</attribute>\n");
		}
		
		if (receivedDate != null) {
			xml.append("      <attribute name=\"" + RECEIVED_DATE + "\">" + 
					DateUtils.formatDate(receivedDate) + "</attribute>\n");
		}
		
		if (createdDate != null) {
			xml.append("      <attribute name=\"" + CREATED_DATE + "\">" + 
					DateUtils.formatDate(createdDate) + "</attribute>\n");
		}
		
		if (toPerson != null) {
			xml.append("      <attribute name=\"" + TO_PERSON + "\">" +
					StringEscapeUtils.escapeXml(toPerson) + "</attribute>\n");
		}
		
		if (fromPerson != null) {
			xml.append("      <attribute name=\"" + FROM_PERSON + "\">" + 
					StringEscapeUtils.escapeXml(fromPerson) + "</attribute>\n");
		}

		if (dispositionDate != null) {
			xml.append("      <attribute name=\"" + DISPOSITION_DATE + "\">" + 
					DateUtils.formatDate(dispositionDate) + "</attribute>\n");
		}
		
		if (masterDocument > 0) {
			xml.append("      <attribute name=\"" + MASTER_DOCUMENT + "\">" + masterDocument + "</attribute>\n");
		}

		xml.append("    </category>\n");
		
		return xml.toString();
	}
}
