package com.cgi.cihr.model;

import java.util.Date;

import org.apache.commons.lang.StringEscapeUtils;

import com.cgi.tools.DateUtils;

/**
 * PROFF Volume model.
 * 
 * @author tomas.hansson
 */
public class ProffVolume {
	private static String CATEGORY = "PROFF Volume";
	private static String BARCODE = "Barcode";
	private static String VOLUME_NO = "Volume No";
	private static String STATUS = "Status";
	private static String START_DATE = "Start Date";
	private static String END_DATE = "End Date";
	private static String LOCATION = "Location";
	private static String BOX = "Box";
	private static String DISPOSITION_DATE = "Disposition Date";
	private static String PROFF_SERIES = "PROFF Series";
	private static String AUTHOR = "Author";
	private static String CREATED_DATE = "Created Date";

	private int barcode;
	private int volumeNo;
	private String status;
	private Date startDate;
	private Date endDate;
	private String location;
	private String box;
	private Date dispositionDate;
	private String proffSeries;
	private String author;
	private Date createdDate;
	
	/**
	 * @param barcode
	 * @param volumeNo
	 * @param status
	 * @param startDate
	 * @param endDate
	 * @param location
	 * @param box
	 * @param dispositionDate
	 * @param proffSeries
	 * @param author
	 * @param createdDate
	 */
	public ProffVolume(int barcode, int volumeNo, String status,
			String startDate, String endDate, String location, String box,
			String dispositionDate, String proffSeries, String author,
			String createdDate) {
		this.barcode = barcode;
		this.volumeNo = volumeNo;
		this.status = status;
		this.startDate = DateUtils.createDate(startDate);
		this.endDate = DateUtils.createDate(endDate);
		this.location = location;
		this.box = box;
		this.dispositionDate = DateUtils.createDate(dispositionDate);
		this.proffSeries = proffSeries;
		this.author = author;
		this.createdDate = DateUtils.createDate(createdDate);
	}


	/**
	 * @return the barcode
	 */
	public int getBarcode() {
		return barcode;
	}


	/**
	 * @param barcode the barcode to set
	 */
	public void setBarcode(int barcode) {
		this.barcode = barcode;
	}


	/**
	 * @return the volumeNo
	 */
	public int getVolumeNo() {
		return volumeNo;
	}


	/**
	 * @param volumeNo the volumeNo to set
	 */
	public void setVolumeNo(int volumeNo) {
		this.volumeNo = volumeNo;
	}


	/**
	 * @return the status
	 */
	public String getStatus() {
		return status;
	}


	/**
	 * @param status the status to set
	 */
	public void setStatus(String status) {
		this.status = status;
	}


	/**
	 * @return the startDate
	 */
	public Date getStartDate() {
		return startDate;
	}


	/**
	 * @param startDate the startDate to set
	 */
	public void setStartDate(Date startDate) {
		this.startDate = startDate;
	}


	/**
	 * @return the endDate
	 */
	public Date getEndDate() {
		return endDate;
	}


	/**
	 * @param endDate the endDate to set
	 */
	public void setEndDate(Date endDate) {
		this.endDate = endDate;
	}


	/**
	 * @return the location
	 */
	public String getLocation() {
		return location;
	}


	/**
	 * @param location the location to set
	 */
	public void setLocation(String location) {
		this.location = location;
	}


	/**
	 * @return the box
	 */
	public String getBox() {
		return box;
	}


	/**
	 * @param box the box to set
	 */
	public void setBox(String box) {
		this.box = box;
	}


	/**
	 * @return the dispositionDate
	 */
	public Date getDispositionDate() {
		return dispositionDate;
	}


	/**
	 * @param dispositionDate the dispositionDate to set
	 */
	public void setDispositionDate(Date dispositionDate) {
		this.dispositionDate = dispositionDate;
	}


	/**
	 * @return the proffSeries
	 */
	public String getProffSeries() {
		return proffSeries;
	}


	/**
	 * @param proffSeries the proffSeries to set
	 */
	public void setProffSeries(String proffSeries) {
		this.proffSeries = proffSeries;
	}


	/**
	 * @return the author
	 */
	public String getAuthor() {
		return author;
	}


	/**
	 * @param author the author to set
	 */
	public void setAuthor(String author) {
		this.author = author;
	}


	/**
	 * @return the createdDate
	 */
	public Date getCreatedDate() {
		return createdDate;
	}


	/**
	 * @param createdDate the createdDate to set
	 */
	public void setCreatedDate(Date createdDate) {
		this.createdDate = createdDate;
	}


	/**
	 * To string class.
	 * 
	 * @return String
	 */
	public String toString() {
		return "ProffVolume [barcode=" + barcode + ", volumeNo=" + volumeNo
				+ ", status=" + status + ", startDate=" + startDate
				+ ", endDate=" + endDate + ", location=" + location + ", box="
				+ box + ", dispositionDate=" + dispositionDate
				+ ", proffSeries=" + proffSeries + ", author=" + author
				+ ", createdDate=" + createdDate + "]";
	}

	/**
	 * Write the category as Importer XML string.
	 * 
	 * @return String
	 */
	public String toXMLString() {
		StringBuffer xml = new StringBuffer();
		
		xml.append("    <category name=\"Livelink Categories:" + CATEGORY + "\">\n");
		xml.append("      <attribute name=\"" + BARCODE + "\">" + barcode + "</attribute>\n");
		xml.append("      <attribute name=\"" + VOLUME_NO + "\">" + volumeNo + "</attribute>\n");			

		if (status != null) {
			xml.append("      <attribute name=\"" + STATUS + "\">" +
					StringEscapeUtils.escapeXml(status) + "</attribute>\n");
		}
		
		if (startDate != null) {
			xml.append("      <attribute name=\"" + START_DATE + "\">" + 
					DateUtils.formatDate(startDate) + "</attribute>\n");
		}
		
		if (endDate != null) {
			xml.append("      <attribute name=\"" + END_DATE + "\">" + 
					DateUtils.formatDate(endDate) + "</attribute>\n");
		}
		
		if (location != null) {
			xml.append("      <attribute name=\"" + LOCATION + "\">" +
					StringEscapeUtils.escapeXml(location) + "</attribute>\n");
		}
		
		if (box != null) {
			xml.append("      <attribute name=\"" + BOX + "\">" + box + "</attribute>\n");
		}

		if (dispositionDate != null) {
			xml.append("      <attribute name=\"" + DISPOSITION_DATE + "\">" + 
					DateUtils.formatDate(dispositionDate) + "</attribute>\n");
		}
		
		xml.append("      <attribute name=\"" + PROFF_SERIES + "\">" + proffSeries + "</attribute>\n");

		if (author != null) {
			xml.append("      <attribute name=\"" + AUTHOR + "\">" + 
					StringEscapeUtils.escapeXml(author) + "</attribute>\n");
		}
		
		if (createdDate != null) {
			xml.append("      <attribute name=\"" + CREATED_DATE + "\">" + 
					DateUtils.formatDate(createdDate) + "</attribute>\n");
		}

		xml.append("    </category>\n");
		
		return xml.toString();
	}
}
