package com.cgi.cihr.model;

import org.apache.commons.lang.StringEscapeUtils;


/**
 * Research Application model.
 * 
 * @author tomas.hansson
 */
public class ResearchApplication {
	private static String CATEGORY = "Research Application";
	private static String COMPETITION = "Competition";
	private static String APPLICATION_NUMBER = "Application Number";
	private static String PIN_NUMBER = "PIN Number";
	private static String FRN_NUMBER = "FRN Number";
	private static String PROJECT_TITLE = "Project Title";
	private static String NPI ="Nominated Principle Investigator";

	private String competition;
	private String applicationNo;
	private String pinNo;
	private String frnNo;
	private String projectTitle;
	private String npi;
	
	/**
	 * Constructor.
	 * 
	 * @param competition
	 * @param applicationNo
	 * @param pinNo
	 * @param frnNo
	 * @param projectTitle
	 * @param npi
	 */
	public ResearchApplication(String competition, String applicationNo,
			String pinNo, String frnNo, String projectTitle, String npi) {
		super();
		this.competition = competition;
		this.applicationNo = applicationNo;
		this.pinNo = pinNo;
		this.frnNo = frnNo;
		this.projectTitle = projectTitle;
		this.npi = npi;
	}

	/**
	 * @return the competition
	 */
	public String getCompetition() {
		return competition;
	}

	/**
	 * @param competition the competition to set
	 */
	public void setCompetition(String competition) {
		this.competition = competition;
	}

	/**
	 * @return the applicationNo
	 */
	public String getApplicationNo() {
		return applicationNo;
	}

	/**
	 * @param applicationNo the applicationNo to set
	 */
	public void setApplicationNo(String applicationNo) {
		this.applicationNo = applicationNo;
	}

	/**
	 * @return the pinNo
	 */
	public String getPinNo() {
		return pinNo;
	}

	/**
	 * @param pinNo the pinNo to set
	 */
	public void setPinNo(String pinNo) {
		this.pinNo = pinNo;
	}

	/**
	 * @return the frnNo
	 */
	public String getFrnNo() {
		return frnNo;
	}

	/**
	 * @param frnNo the frnNo to set
	 */
	public void setFrnNo(String frnNo) {
		this.frnNo = frnNo;
	}

	/**
	 * @return the projectTitle
	 */
	public String getProjectTitle() {
		return projectTitle;
	}

	/**
	 * @param projectTitle the projectTitle to set
	 */
	public void setProjectTitle(String projectTitle) {
		this.projectTitle = projectTitle;
	}

	/**
	 * @return the npi
	 */
	public String getNpi() {
		return npi;
	}

	/**
	 * @param npi the npi to set
	 */
	public void setNpi(String npi) {
		this.npi = npi;
	}

	/**
	 * To string.
	 * 
	 * @return String
	 */
	public String toString() {
		return "ResearchApplication [competition=" + competition
				+ ", applicationNo=" + applicationNo + ", pinNo=" + pinNo
				+ ", frnNo=" + frnNo + ", projectTitle=" + projectTitle
				+ ", npi=" + npi + "]";
	}

	/**
	 * Write the category as Importer XML string.
	 * 
	 * @return String
	 */
	public String toXMLString() {
		StringBuffer xml = new StringBuffer();
		String txt = null;
		
		xml.append("    <category name=\"Livelink Categories:" + CATEGORY + "\">\n");
		xml.append("      <attribute name=\"" + COMPETITION + "\">");
		 
		if (competition == null) {
			txt = "N/A";
		} else {
			txt = StringEscapeUtils.escapeXml(competition);
		}
		
		xml.append(txt + "</attribute>\n");
		xml.append("      <attribute name=\"" + APPLICATION_NUMBER + "\">");
		
		if (applicationNo == null) {
			txt = "N/A";
		} else {
			txt = applicationNo;
		}
		
		xml.append(txt + "</attribute>\n");
		xml.append("      <attribute name=\"" + PIN_NUMBER + "\">" + pinNo + "</attribute>\n");
		
		if (frnNo != null) {
			xml.append("      <attribute name=\"" + FRN_NUMBER + "\">" + 
					StringEscapeUtils.escapeXml(frnNo) + "</attribute>\n");
		}

		if (projectTitle != null) {
			xml.append("      <attribute name=\"" + PROJECT_TITLE + "\">" + 
					StringEscapeUtils.escapeXml(projectTitle) + "</attribute>\n");
		}
		
		if (npi != null) {
			xml.append("      <attribute name=\"" + NPI + "\">" + 
					StringEscapeUtils.escapeXml(npi) + "</attribute>\n");
		}

		xml.append("    </category>\n");
		
		return xml.toString();
	}
}
