package com.cgi.cihr.readers;

import java.io.IOException;
import java.io.Reader;
import java.util.Map;

import org.supercsv.cellprocessor.Optional;
import org.supercsv.cellprocessor.ParseInt;
import org.supercsv.cellprocessor.constraint.StrMinMax;
import org.supercsv.cellprocessor.constraint.StrNotNullOrEmpty;
import org.supercsv.cellprocessor.constraint.Strlen;
import org.supercsv.cellprocessor.ift.CellProcessor;
import org.supercsv.io.CsvMapReader;
import org.supercsv.prefs.CsvPreference;

/**
 * CSV PROFF table reader.
 * 
 * @author tomas.hansson
 */
public class ProffReader {
	private CsvMapReader csvReader;
	
	private CellProcessor[] processors = new CellProcessor[] {
			new StrNotNullOrEmpty(),					// OBJECTTYPE
			new ParseInt(),								// ORDER
			new StrNotNullOrEmpty(),					// TITLE
			new Optional(new ParseInt()),				// VOLUMENO
			new StrNotNullOrEmpty(),					// SERIESCLASS
			new StrNotNullOrEmpty(),					// ROOT_CLASS
			new ParseInt(),								// BARCODE
			new Optional(),								// FOLDERBOX
			new Optional(),								// FOLDERLOCATION
			new Optional(),								// FOLDERSTARTDATE
			new Optional(),								// FOLDERENDDATE
			new Optional(),								// APPNUMBER
			new Optional(),								// COMPETITION
			new Optional(),								// PIN
			new Optional(),								// DESCRIPTION
			new Optional(),								// FRN
			new Optional(new Strlen(1)),				// FOLDERSTATUS
			new Optional(),								// FOLDERDISPDATE
			new Optional(),								// AUTHOR
			new Optional(),								// CREATEDDATE
			new Optional(new StrMinMax(0, 3)),			// DOCUMENT_TYPE
			new Optional(),								// RECEIVED_DATE
			new Optional(),								// TO_PERSON
			new Optional(),								// FROM_PERSON
			new Optional(),								// DOCUMENTDISPDATE
			new Optional(new ParseInt()),				// MASTERDOCUMENT
			new Optional(new ParseInt())				// DOCUMENTNO
		};
		
	private String[] header = new String[] {
			"objectType", "order", "title", "volumeNo", "seriesClass", "rootClass", "barCode", "folderBox", 
			"folderLocation", "folderStartDate", "folderEndDate", "appNumber", "competition", "pin",
			"description", "frn", "folderStatus", "folderDispDate", "author", "createdDate", "documentType",
			"receivedDate", "toPerson", "fromPerson", "documentDispDate", "masterDocument", "documentNo"
		};

	/**
	 * Constructor.
	 * 
	 * @param reader
	 */
	public ProffReader(Reader reader) {
		csvReader = new CsvMapReader(reader, CsvPreference.STANDARD_PREFERENCE);
		
		// Skip the header row
		try {
			csvReader.getCSVHeader(false);
		} catch (IOException e) {
			// Do nothing
		}
	}
	
	/**
	 * Read the map from CVS file.
	 * 
	 * @return Map<String, ? super Object>
	 * @throws IOException
	 */
	public Map<String, ? super Object> read() throws IOException {
		Map<String, ? super Object> m = csvReader.read(header, processors);
		
		return m;
	}
	
	/**
	 * Close.
	 * 
	 * @throws IOException
	 */
	public void close() throws IOException {
		csvReader.close();
	}
}
