package com.cgi.cihr.writers;

import java.io.IOException;
import java.util.List;

import org.apache.commons.lang.StringEscapeUtils;

import com.cgi.cihr.model.CheckOut;
import com.cgi.cihr.model.HRVolume;
import com.cgi.cihr.model.ProffBox;
import com.cgi.cihr.model.ProffDocument;
import com.cgi.cihr.model.ProffVolume;
import com.cgi.cihr.model.ResearchApplication;


/**
 * Writer for control text files.
 * 
 * @author tomas.hansson
  */
public class TextControlFileWriter extends ControlFileWriter {
	private static final String SUFFIX = "txt";
	
	/**
	 * Constructor.
	 * 
	 * @param location
	 * @throws IOException
	 */
	public TextControlFileWriter(String location) throws IOException {
		super(location, SUFFIX, false);
	}
	
	/**
	 * Text info for folder.
	 * 
	 * @param location
	 * @param title
	 * @param description
	 * @param securityLevel
	 * @throws IOException
	 */
	public void createFolder(String location, String title,
			String description, String securityLevel) throws IOException {
		String info = "Folder: " + StringEscapeUtils.escapeXml(location) + ":" + 
			StringEscapeUtils.escapeXml(title).replace(':', '-') +
			"\n    Desc.: " + StringEscapeUtils.escapeXml(description) +
			" Sec (" + securityLevel + ")\n";
	
		writeRecord(info);
	}
	
	/**
	 * Text info for volume.
	 * 
	 * @param id
	 * @param location
	 * @param title
	 * @param description
	 * @param objId
	 * @param physicalLocation
	 * @param securityLevel
	 * @param co
	 * @param ra
	 * @param pv
	 * @param hr
	 * @throws IOException
	 */
	public void createVolume(int id, String location, String title, String description,
			int objId, String physicalLocation, String securityLevel,
			CheckOut co, ResearchApplication ra, ProffVolume pv, HRVolume hr) throws IOException {
		StringBuffer s = new StringBuffer();
		
		s.append("Volume: " + StringEscapeUtils.escapeXml(location) + ":" + 
				StringEscapeUtils.escapeXml(title).replace(':', '-') + " Desc: " + description + 
				" PhysLoc: " + physicalLocation + " Unique Id: " + id + " Sec Clrnc: " + 
				securityLevel + " Objid: " + objId);
		
		if (co != null) {
			s.append("\n  Checked-out: " + co);
		}
		
		if (ra != null) {
			s.append("\n  RA Category: " + ra);
		}
		
		if (pv != null) {
			s.append("\n  PV Category: " + pv);
		}
		
		if (hr != null) {
			s.append("\n HR Category: " + hr);
		}
		
		s.append("\n");
		
		writeRecord(s.toString());		
	}	
	
	/**
	 * XML to create a physical document.
	 * 
	 * @param docNo
	 * @param location
	 * @param title
	 * @param description
	 * @param documentObjId
	 * @param physicalLocation
	 * @param securityLevel
	 * @param pd
	 * @throws IOException
	 */
	public void createDocument(int docNo, String location, String title, String description, 
			String documentObjId, String physicalLocation, String securityLevel,
			ProffDocument pd) throws IOException {
		StringBuffer s = new StringBuffer();
		
		s.append("Document :" + StringEscapeUtils.escapeXml(location) + ":" +
			StringEscapeUtils.escapeXml(title).replace(':', '-') + " Desc: " + description +
			" PhysLoc: " + physicalLocation + " Doc No: " + docNo + " Sec Clrnc: " + securityLevel);
		
		if (pd != null) {
			s.append("\n  PD Category: " + pd);
		}
		
		s.append("\n");
		
		writeRecord(s.toString());
	}	
	
	/**
	 * Create a box with included volumes.
	 * 
	 * @param location
	 * @param title
	 * @param boxObjId
	 * @param physicalLocation
	 * @param securityLevel
	 * @param pb
	 * @param idList
	 * @throws IOException
	 */
	public void createBox(String location, String title, 
			String boxObjId, String physicalLocation, String securityLevel,
			ProffBox pb, List<Integer> idList) throws IOException {
		StringBuffer s = new StringBuffer();
		
		s.append("Box: " + StringEscapeUtils.escapeXml(location) + ":" +
				StringEscapeUtils.escapeXml(title).replace(':', '-') + " PhysLoc: " +
				physicalLocation + " Sec Clrnc: " + securityLevel + "Ids: ");
		
		for (int id : idList) {
			s.append(id + " ");
		}
				
		if (pb != null) {
			s.append("\n  PB Category: " + pb);
		}
		
		s.append("\n");
			
		writeRecord(s.toString());		
	}	
}
