package com.cgi.tools;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

/**
 * Date utilities.
 * 
 * @author tomas.hansson
 */
public class DateUtils {
	private static DateFormat df = new SimpleDateFormat("yyyyMMdd");
	
	/**
	 * Create a date given a string.
	 * 
	 * @param str
	 * @return Date
	 */
	public static Date createDate(String str) {		
		if (str == null || str.length() < 10) {
			return null;
		}
		
		int year = Integer.parseInt(str.substring(0, 4));
		int month = Integer.parseInt(str.substring(5, 7)) - 1;
		int day = Integer.parseInt(str.substring(8, 10));
		
		// Sanity check for bad dates
		if (year < 1950 || year > 2050) {
			return null;
		}
		
		Calendar cal = new GregorianCalendar(year, month, day);

		return cal.getTime();
	}
	
	/**
	 * Format a date.
	 * 
	 * @param d
	 * @return String
	 */
	public static String formatDate(Date d) {
		String s = "";
	
		if (d != null) {
			s = df.format(d);
		}
		
		return s;
	}
}
